@@ -1,12 +1,13 @@
 from unittest import TestCase
 
 import pytest
+from pydantic import BaseModel, Field
 
 from pipeline import (
     Message,
-    DescribeMessage,
+    Command,
+    Definition,
     PipelineMessageError,
-    serialize_message,
     deserialize_message,
 )
 
@@ -21,17 +22,17 @@ class TestMessage(TestCase):
 
     def test_serialization(self):
         message = Message(content={"key": "message"})
-        result = deserialize_message(serialize_message(message))
+        result = deserialize_message(message.serialize())
         self.assertDictEqual(message.content, result.content)
 
     def test_serialization_describe(self):
-        message = DescribeMessage()
-        result = deserialize_message(serialize_message(message))
-        self.assertDictEqual(message.dict(), result.dict())
+        command = Command(action="CustomAction")
+        result = deserialize_message(command.serialize())
+        self.assertDictEqual(command.dict(), result.dict())
 
     def test_serialization_compression(self):
         message = Message(content={"key": "message"})
-        result = deserialize_message(serialize_message(message, compress=True))
+        result = deserialize_message(message.serialize(compress=True))
         self.assertDictEqual(message.content, result.content)
 
     def test_serialization_compression_unicode(self):
@@ -55,5 +56,19 @@ class TestMessage(TestCase):
         with pytest.raises(PipelineMessageError):
             Message.deserialize(b"HFHGKDJFHG")
 
-    def test_describe(self):
-        DescribeMessage()
+    def test_definition(self):
+        class Input(BaseModel):
+            text: str = Field(..., title="text", description="input text")
+
+        class Output(BaseModel):
+            probability: float = Field(..., title="prob", description="probability")
+
+        definition1 = Definition(
+            name="worker",
+            version="0.1.0",
+            description="worker",
+            input_schema=Input.schema(),
+            output_schema=Output.schema(),
+        )
+
+        assert definition1
